@@ -7,10 +7,10 @@ from trytond.model import ModelView, Workflow, fields
 from trytond.pyson import Eval, Bool
 
 __all__ = ['Journal', 'Payment']
-__metaclass__ = PoolMeta
 
 
 class Journal:
+    __metaclass__ = PoolMeta
     __name__ = 'account.payment.journal'
     clearing_account = fields.Many2One('account.account', 'Clearing Account',
         domain=[('party_required', '=', False)],
@@ -26,6 +26,7 @@ class Journal:
 
 
 class Payment:
+    __metaclass__ = PoolMeta
     __name__ = 'account.payment'
     clearing_move = fields.Many2One('account.move', 'Clearing Move',
         readonly=True)
@@ -50,7 +51,7 @@ class Payment:
             cls.write(*sum((([m.origin], {'clearing_move': m.id})
                         for m in moves), ()))
 
-        to_reconcile = defaultdict(list)
+        to_reconcile = []
         for payment in payments:
             if (payment.line
                     and not payment.line.reconciliation
@@ -58,8 +59,8 @@ class Payment:
                 lines = [l for l in payment.clearing_move.lines
                     if l.account == payment.line.account] + [payment.line]
                 if not sum(l.debit - l.credit for l in lines):
-                    to_reconcile[payment.party].extend(lines)
-        for lines in to_reconcile.itervalues():
+                    to_reconcile.append(lines)
+        for lines in to_reconcile:
             Line.reconcile(lines)
 
     def create_clearing_move(self, date=None):
